@@ -1,4 +1,4 @@
-# $Revision: 1.39 $$Date: 2005-05-23 10:23:27 -0400 (Mon, 23 May 2005) $$Author: wsnyder $
+# $Revision: 1.39 $$Date: 2005-06-17 14:47:20 -0400 (Fri, 17 Jun 2005) $$Author: wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -18,7 +18,7 @@ use vars qw ($Default_Self $VERSION);
 use Carp;
 use strict;
 
-$VERSION = '1.261';
+$VERSION = '1.300';
 
 ######################################################################
 # Default rules
@@ -42,7 +42,7 @@ sub _default_rules {
 		    ."    operator en () const { return m_e; }\n"
 		    ."    const char * ascii () const;\n"
 		    );
-	    if ($self->{attributes}{descfunc}) {
+	    if ($self->attribute_value('descfunc')) {
 		fprint ("    const char * description () const;\n");
 	    }
 	});
